﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.ComponentModel;
using System.Collections.ObjectModel;
using Infragistics.Controls.Charts;

namespace BarSeriesHight
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
        public MainWindow()
        {
            InitializeComponent();
            var rect1Data = Data.GetData(1, -33, -21);
            var rect2Data = Data.GetData(2, 39, 47);
            var rect3Data = Data.GetData(3, -53, -48);
            DataContext = rect1Data.Concat(rect2Data).Concat(rect3Data);

            x.Gap = 1;
            y.MinimumValue = -53.3 - 20;
            y.MaximumValue = 41.7 + 20;
            y.CrossingValue = y.MinimumValue;
            series.ItemsSource = (IEnumerable<Data>)DataContext;
            series.XAxis = x;
            series.YAxis = y;
            series.ValueMemberPath = "High";
            //SetToolTip(series);
            xd.Series.Add(series);
            xd.Axes.Add(x);
            xd.Axes.Add(y);
        }

        //private static void SetToolTip(ColumnSeries series)
        //{
        //    StackPanel sp = new StackPanel();
        //    TextBlock tb1 = new TextBlock();
        //    TextBlock tb2 = new TextBlock();
        //    sp.Children.Add(tb1);
        //    sp.Children.Add(tb2);
        //    tb1.SetBinding(TextBlock.TextProperty, new Binding("Item.Label"));
        //    tb2.SetBinding(TextBlock.TextProperty, new Binding("Item.High"));
        //    series.ToolTip = sp;
        //}

        private void series_AssigningCategoryStyle(object sender, Infragistics.Controls.Charts.AssigningCategoryStyleEventArgs args)
        {
            args.Fill = (args.GetItems(args.StartIndex, args.EndIndex).First() as Data).Color;
        }
	}

	public class Data : INotifyPropertyChanged
	{
		private int open;
		private int close;
		private int high;
		private int low;
		private int value;
		private string label;
		private DateTime date;


		public DateTime Date
		{
			get { return date; }
			set
			{
				date = value;
				PropChanged("Date");
			}
		}


		public string Label
		{
			get { return label; }
			set
			{
				label = value;
				PropChanged("Label");
			}
		}

		public int Open
		{
			get { return open; }
			set
			{
				open = value;
				PropChanged("Open");
			}
		}

		public int Close
		{
			get { return close; }
			set
			{
				close = value;
				PropChanged("Close");
			}
		}

		public int High
		{
			get { return high; }
			set
			{
				high = value;
				PropChanged("High");
			}
		}

		public int Low
		{
			get { return low; }
			set
			{
				low = value;
				PropChanged("Low");
			}
		}

		public int Value
		{
			get { return value; }
			set
			{
				this.value = value;
				PropChanged("Value");
			}
		}

		private GradientBrush _color;
        public GradientBrush Color
		{
			get { return _color; }
			set
			{
				this._color = value;
				PropChanged("Color");
			}
		}

		public double Avarage
		{
			get
			{
				return (Open + Close + High + Low) / 4;
			}
		}

		static Random r = new Random();
		public static ObservableCollection<Data> GetData(int points, int rangeStart, int rangeEnd)
		{
			ObservableCollection<Data> data = new ObservableCollection<Data>();
			int red = r.Next(0, byte.MaxValue + 1);
			int green = r.Next(0, byte.MaxValue + 1);
			int blue = r.Next(0, byte.MaxValue + 1);
            var startColor = System.Windows.Media.Color.FromRgb((byte)blue, (byte)green, (byte)red);
            var endColor = System.Windows.Media.Color.FromRgb((byte)red, (byte)green, (byte)blue);
			data.Add(new Data
			{
				Date = DateTime.Now.AddDays(points),
				Label = "Item " + points,
				Open = r.Next(rangeStart, rangeEnd),
				Close = r.Next(rangeStart, rangeEnd),
				High = r.Next(rangeStart, rangeEnd),
				Low = points,
                Color = new LinearGradientBrush(startColor, endColor, 10)
			});
			return data;
		}

		public event PropertyChangedEventHandler PropertyChanged;

		public void PropChanged(string name)
		{
			if (PropertyChanged != null)
				PropertyChanged(this, new PropertyChangedEventArgs(name));
		}
	}

}